@@ -232,7 +232,7 @@ def wrap_locally_cst_func(func):
         # !! In Python 2.7+, dictionary comprehension: {argname:...}
         kwargs_float = dict(
             (arg_name, uncert_core.nominal_value(value))
-            for (arg_name, value) in kwargs.items())
+            for (arg_name, value) in iter(kwargs.items()))
         return func(*args_float, **kwargs_float)
     return wrapped_func
 
